#!/usr/bin/perl -w
# 
# sb::Plugin::SetThumbnailQuality - Plugin Module for Serene Bach
# - Written by Gin-Lime / published on 2006-05-09
# -- `Serene Bach' is written by T.Otani
# --   Copyright (C) 2005- SimpleBoxes/SerendipityNZ.

package sb::Plugin::SetThumbnailQuality;
# ==================================================
# // initialization for plugin
# ==================================================
use sb::Plugin ();
sb::Plugin->register_plugin(
	'lang' => {
		'ja' => 'euc',
		'en' => 'ascii',
	},
	'text' => {
		'type'    => 'admin, extra',
		'name'    => 'Set Thumbnail Quality',
		'text'    => 'Changes quality setting of creating thumbnails',
		'author'  => 'Gin-Lime',
		'detail'  => 'http://www.emeraldshell.com/sb/',
		'version' => '0.01',
		'publish' => 'yes',	# ץ饰ꥹȤΤγĥʸ/
	},
	'file' => 'setthumbnailquality.txt',
	'data' => 1,
);
# adminѥץ饰ȤϿ
sb::Plugin->register_admin_module(
	'mode'   => 'setthumbnailquality',
	'level'  => 2,
	'module' => 'sb::Admin::SetThumbnailQuality',
);
# ץ饰ͭ˥С饤ɤ
sub _init {
	my $name = __FILE__;
	$name =~ s/.*[:\/\\](.*)/$1/;
	if(!&sb::Plugin::_ignore_plugin($name)) {
		use sb::Data::Image();
		*sb::Data::Image::_create_smallimage = \&_create_smallimage;
	}
}
&_init();
# ==================================================
# // function override
# ==================================================
use sb::Data::Image ();
sub _create_smallimage {
	# create a thumbnail image via Image::Magick
	my ($thumb,$file,$dir,$size) = @_;
	return( undef ) if ($file eq '' or $thumb eq '' or $dir eq '');
	my $quality = &sb::Plugin::SetThumbnailQuality::_load_setting;	# by GLM
	eval {
		require Image::Magick;
		my $old = Image::Magick->new;
		$old->Read($dir . $file);
		my ($w,$h) = $old->Get('width','height');
		($w,$h) = &sb::Data::Image::_resize($w,$h,$size,$size);
		my $new = $old->Clone();
		$new->Set(quality=>$quality);	# by GLM
		$new->Scale('width'=>$w,'height'=>$h);
		$new->Write("$dir$thumb");
		chmod(sb::Config->get->value('basic_file_attr'),$dir . $thumb) if (-e $dir . $thumb);
	};
	return ($@) ? undef : 1;
}
# ==================================================
# // private functions - other utilities
# ==================================================
sub _load_setting {
	my $set_data = sb::Plugin->get_data;
	my $out = ($set_data->setting ne '') ? $set_data->setting : &sb::Admin::SetThumbnailQuality::DEFAULT_QUALITY;
	$out = int($out);
	return($out);
}

package sb::Admin::SetThumbnailQuality;
use vars qw( @ISA );
use sb::Interface ();
use sb::TemplateManager ();
use sb::Language ();
@ISA = qw( sb::App::Admin );
# ==================================================
# // declaration for constant value
# ==================================================
sub TEMPLATE  (){ 'setthumbnailquality.html' };
# ɸβ
sub DEFAULT_QUALITY (){ '75' };
# ==================================================
# // public functions - callback
# ==================================================
sub callback {
	my $self = shift;
	return ( $self->{'regi'} ) 
		? $self->_save_setting(@_)
		: $self->_show_setting(@_);
}
# ==================================================
# // private functions - main routine
# ==================================================
sub _save_setting {
	my $self = shift;
	my $cgi  = sb::Interface->get;
	# ǡμ
	my $data = sb::Plugin->get_data;

	# μ
	$data->setting($cgi->value('thumbnail_quality'));

	# ǡ¸
	sb::Plugin->set_data('data' => $data);

	# ¸λåɽ
	my $lang = sb::Language->get;
	my $msg = $lang->string('parts_confcomp');
	$msg .= $lang->string('parts_stq_need_uploadagain');
	return $self->_show_setting('message'=>$msg);
}
sub _show_setting {
	my $self = shift;
	my %param = ('message' => '', @_);
	my $cms  = sb::TemplateManager->new(sb::Plugin->load_template('file' => TEMPLATE));

	my $set_data = sb::Plugin->get_data;
	my $quality = ($set_data->setting ne '') ? $set_data->setting : DEFAULT_QUALITY;
	$quality = int($quality);

	my $lang = sb::Language->get;

	my $quality_option = '';
	for(my $i = 100; $i >= 0; $i--){
		$quality_option .= '<option value="' . $i . '"';
		if($i == $quality) {
			$quality_option .= ' selected';
		}
		$quality_option .= '>' . $i;
		if($i == 100) {
			$quality_option .= $lang->string('parts_stq_quality_highest');
		} elsif($i == 90) {
			$quality_option .= $lang->string('parts_stq_quality_high');
		} elsif($i == 75) {
			$quality_option .= $lang->string('parts_stq_quality_default');
		} elsif($i == 50) {
			$quality_option .= $lang->string('parts_stq_quality_low');
		} elsif($i == 0) {
			$quality_option .= $lang->string('parts_stq_quality_lowest');
		}
		$quality_option .= '</option>' . "\n";
	}

	# ȼͤ
	$cms->num(0);
	$cms->tag('stq_thumbnail_quality' => $quality_option );
	$cms->tag('stq_quality_now' => $quality );

	# åɽ
	if ($param{'message'} ne '') {
		$cms->num(0);
		$cms->tag('sb_process_message' => $param{'message'});
		$cms->block('sb_process_message' => 1);
	}

	# ̤ɽ
	return sb::Interface->get->head('type'=>'text/html') . $self->set_main($cms->output);
}

1;
# require 뤿Τޤʤ
__END__

Original function overridden

*sb::Data::Image
Version:0.05

sub _create_smallimage {
	# create a thumbnail image via Image::Magick
	my ($thumb,$file,$dir,$size) = @_;
	return( undef ) if ($file eq '' or $thumb eq '' or $dir eq '');
	eval {
		require Image::Magick;
		my $old = Image::Magick->new;
		$old->Read($dir . $file);
		my ($w,$h) = $old->Get('width','height');
		($w,$h) = &_resize($w,$h,$size,$size);
		my $new = $old->Clone();
		$new->Scale('width'=>$w,'height'=>$h);
		$new->Write("$dir$thumb");
		chmod(sb::Config->get->value('basic_file_attr'),$dir . $thumb) if (-e $dir . $thumb);
	};
	return ($@) ? undef : 1;
}

